==> aom-docs-3.0.0-2-aarch64.pkg.tar.xz: usr/share/doc/aom/group__rate__control.js <==
var group__rate__control =
[
    [ "av1_first_pass", "group__rate__control.html#ga2a0f590eb2dc358f9781654644a2519d", null ],
    [ "av1_gop_setup_structure", "group__rate__control.html#ga6853e4fcc63f2f54ae429e27286827ae", null ],
    [ "av1_gop_bit_allocation", "group__rate__control.html#gac12d62af325ff26685a28bebb0137a65", null ],
    [ "av1_get_second_pass_params", "group__rate__control.html#gaa5b125ad159f53b6ee5423900e479c0b", null ],
    [ "av1_twopass_postencode_update", "group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544", null ],
    [ "get_twopass_worst_quality", "group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f", null ],
    [ "calculate_total_gf_group_bits", "group__rate__control.html#gaa1b79c4de593c5ddccf4f0384d51e901", null ],
    [ "get_rate_correction_factor", "group__rate__control.html#ga2739ae83fcd1266a2b44aae1ee40e57f", null ],
    [ "set_rate_correction_factor", "group__rate__control.html#gae9e6431ebd75ca58a1e526f91cc0cea8", null ],
    [ "find_closest_qindex_by_rate", "group__rate__control.html#ga8cc1e01e3fb0a620ea3a7ab53d94eb6e", null ],
    [ "rc_pick_q_and_bounds_no_stats_cbr", "group__rate__control.html#gad9722dabdd6c62b9d2fac0551b83fe89", null ],
    [ "get_q_using_fixed_offsets", "group__rate__control.html#gab0e270ba5341f6881b20970a82567eae", null ],
    [ "rc_pick_q_and_bounds_no_stats", "group__rate__control.html#gabc57b9de63d930432a3ed6ee98206c96", null ],
    [ "get_q", "group__rate__control.html#gabbdc0f8c7b275c67917af9e49a0a18ce", null ],
    [ "rc_pick_q_and_bounds", "group__rate__control.html#ga788dbcf3c2f97056f0ca1fd644a4535f", null ],
    [ "av1_set_reference_structure_one_pass_rt", "group__rate__control.html#ga671ccd88dfed2d5be8f6c586910ab89e", null ],
    [ "rc_scene_detection_onepass_rt", "group__rate__control.html#ga06eb20a95903f261d8e9a86f6a359927", null ],
    [ "set_gf_interval_update_onepass_rt", "group__rate__control.html#ga7778c29e995a78b2521fe4f0bab0c9c1", null ],
    [ "dynamic_resize_one_pass_cbr", "group__rate__control.html#ga4770b9bf9d2f350267d57a8dcc48d0a2", null ],
    [ "av1_rc_update_rate_correction_factors", "group__rate__control.html#gaf4845f52af8f34c200706e1c3e14614f", null ],
    [ "av1_rc_pick_q_and_bounds", "group__rate__control.html#ga204806353e37338b8d901c79dbc39523", null ],
    [ "av1_rc_regulate_q", "group__rate__control.html#gacff14724140f9a2419bc82ef61ef2845", null ],
    [ "av1_calc_pframe_target_size_one_pass_vbr", "group__rate__control.html#ga174d96c77a72a090d5e218346a91d4c2", null ],
    [ "av1_calc_iframe_target_size_one_pass_vbr", "group__rate__control.html#gac4b060420e6d43e341ce36cadbb2ff93", null ],
    [ "av1_calc_pframe_target_size_one_pass_cbr", "group__rate__control.html#ga653667e5cc76259acc233c1986546599", null ],
    [ "av1_calc_iframe_target_size_one_pass_cbr", "group__rate__control.html#gab8e7c90f91decf78f31360e56b7f1be6", null ],
    [ "av1_get_one_pass_rt_params", "group__rate__control.html#gae79c4d7e1bb558a1c2b4cd9da69b77c7", null ],
    [ "av1_encodedframe_overshoot_cbr", "group__rate__control.html#ga4d75c27a723a602ab5b4c497cea07993", null ],
    [ "recode_loop_test", "group__rate__control.html#ga9c1efbd9f79914ed44ee7a6a795381d5", null ],
    [ "recode_loop_update_q", "group__rate__control.html#gacd9a4ebbc3f3c5203419152558dcb17a", null ],
    [ "get_layer_context", "group__rate__control.html#gaf8a538f6c9543dcc032fd688da6cb992", null ]
];

==> aom-docs-3.3.0-1-aarch64.pkg.tar.xz: usr/share/doc/aom/group__rate__control.js <==
var group__rate__control =
[
    [ "av1_firstpass_info_init", "group__rate__control.html#ga697e00462bcbc3165ed0f7bd25a88925", null ],
    [ "av1_firstpass_info_move_cur_index", "group__rate__control.html#ga1f1b566e7234deb8018a0bd3dc3822d7", null ],
    [ "av1_firstpass_info_pop", "group__rate__control.html#ga45ce59a77756df79d6fdbdae82158a41", null ],
    [ "av1_firstpass_info_move_cur_index_and_pop", "group__rate__control.html#ga81e2619f5917dda2803f37c76080c3e5", null ],
    [ "av1_firstpass_info_push", "group__rate__control.html#ga05ee091c593e5672c6be2d0bdd89d1cb", null ],
    [ "av1_firstpass_info_peek", "group__rate__control.html#ga1930a02e62c42b75313b987806837c84", null ],
    [ "av1_firstpass_info_future_count", "group__rate__control.html#gadfe05128d22bba397120763fe132c867", null ],
    [ "av1_firstpass_info_past_count", "group__rate__control.html#ga6ae4ccee614dac82eb20d16c30d6cbe9", null ],
    [ "av1_first_pass", "group__rate__control.html#ga2a0f590eb2dc358f9781654644a2519d", null ],
    [ "av1_gop_setup_structure", "group__rate__control.html#ga6853e4fcc63f2f54ae429e27286827ae", null ],
    [ "av1_gop_bit_allocation", "group__rate__control.html#gac12d62af325ff26685a28bebb0137a65", null ],
    [ "av1_gop_check_forward_keyframe", "group__rate__control.html#gac1743a047b06169064f57c74288d7537", null ],
    [ "av1_gop_is_second_arf", "group__rate__control.html#ga50283a647b83308a9a7c02b74a980ac1", null ],
    [ "av1_get_second_pass_params", "group__rate__control.html#ga2c30e6d5b7f0c87a7aa61cabace6905c", null ],
    [ "av1_twopass_postencode_update", "group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544", null ],
    [ "get_twopass_worst_quality", "group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f", null ],
    [ "calculate_total_gf_group_bits", "group__rate__control.html#gaa1b79c4de593c5ddccf4f0384d51e901", null ],
    [ "get_rate_correction_factor", "group__rate__control.html#ga2739ae83fcd1266a2b44aae1ee40e57f", null ],
    [ "set_rate_correction_factor", "group__rate__control.html#gae9e6431ebd75ca58a1e526f91cc0cea8", null ],
    [ "find_closest_qindex_by_rate", "group__rate__control.html#ga8cc1e01e3fb0a620ea3a7ab53d94eb6e", null ],
    [ "rc_pick_q_and_bounds_no_stats_cbr", "group__rate__control.html#gad9722dabdd6c62b9d2fac0551b83fe89", null ],
    [ "rc_pick_q_and_bounds_no_stats", "group__rate__control.html#gabfb0989110479fa704a1b245a4c4c1cf", null ],
    [ "get_q", "group__rate__control.html#gabbdc0f8c7b275c67917af9e49a0a18ce", null ],
    [ "rc_pick_q_and_bounds", "group__rate__control.html#ga788dbcf3c2f97056f0ca1fd644a4535f", null ],
    [ "av1_set_reference_structure_one_pass_rt", "group__rate__control.html#ga671ccd88dfed2d5be8f6c586910ab89e", null ],
    [ "rc_scene_detection_onepass_rt", "group__rate__control.html#ga06eb20a95903f261d8e9a86f6a359927", null ],
    [ "set_gf_interval_update_onepass_rt", "group__rate__control.html#ga7778c29e995a78b2521fe4f0bab0c9c1", null ],
    [ "dynamic_resize_one_pass_cbr", "group__rate__control.html#ga4770b9bf9d2f350267d57a8dcc48d0a2", null ],
    [ "av1_rc_update_rate_correction_factors", "group__rate__control.html#gaf4845f52af8f34c200706e1c3e14614f", null ],
    [ "av1_rc_pick_q_and_bounds", "group__rate__control.html#gaabc94f144903517a3d4aff8f65da1638", null ],
    [ "av1_rc_regulate_q", "group__rate__control.html#gacff14724140f9a2419bc82ef61ef2845", null ],
    [ "av1_calc_pframe_target_size_one_pass_vbr", "group__rate__control.html#ga174d96c77a72a090d5e218346a91d4c2", null ],
    [ "av1_calc_iframe_target_size_one_pass_vbr", "group__rate__control.html#gac4b060420e6d43e341ce36cadbb2ff93", null ],
    [ "av1_calc_pframe_target_size_one_pass_cbr", "group__rate__control.html#ga653667e5cc76259acc233c1986546599", null ],
    [ "av1_calc_iframe_target_size_one_pass_cbr", "group__rate__control.html#gab8e7c90f91decf78f31360e56b7f1be6", null ],
    [ "av1_get_one_pass_rt_params", "group__rate__control.html#gae79c4d7e1bb558a1c2b4cd9da69b77c7", null ],
    [ "av1_encodedframe_overshoot_cbr", "group__rate__control.html#ga4d75c27a723a602ab5b4c497cea07993", null ],
    [ "recode_loop_test", "group__rate__control.html#ga9c1efbd9f79914ed44ee7a6a795381d5", null ],
    [ "recode_loop_update_q", "group__rate__control.html#gacd9a4ebbc3f3c5203419152558dcb17a", null ],
    [ "get_layer_context", "group__rate__control.html#ga08d8e6c33750a282d5a9dc66252fda45", null ]
];
